/* This file is part of guile-sql.
   Copyright (C) 2002 Sergey Poznyakoff

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif
#include <guile-sql.h>
#include <app.h>

SCM 
scm_makenum (unsigned long val)
{
  if (SCM_FIXABLE ((long) val))
    return SCM_MAKINUM (val);

#ifdef SCM_BIGDIG
  return scm_long2big (val);
#else /* SCM_BIGDIG */
  return scm_make_real ((double) val);
#endif /* SCM_BIGDIG */
}

/*
 * Chop off trailing whitespace. Return length of the resulting string
 */
int
chop(char *str)
{
  int len;
  
  for (len = strlen(str); len > 0 && isspace(str[len-1]); len--)
    ;
  str[len] = 0;
  return len;
}

void
init_util_sql()
{
	gsql_conn_init();
#ifdef USE_SQL_MYSQL
	sql_register_iface(&mysql_iface);
#endif
#ifdef USE_SQL_PGSQL
	sql_register_iface(&pgsql_iface);
#endif
}

extern void
scm_init_util_sql_module()
{
	scm_register_module_xxx ("util sql", init_util_sql);
}

